@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.3.0/src/abt_jobinfo.cpp $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/abt_jobinfo.cpp $
  * $Author: Patrick Wacker $
- * $Date: 2012-04-17 11:56:20 +0200 (Tue, 17 Apr 2012) $
- * $Rev: 244 $
+ * $Date: 2013-03-10 10:25:59 +0100 (Sun, 10 Mar 2013) $
+ * $Rev: 363 $
  *
  * description:
  *	Abstraction of an AB_JOB, used at "Ausgang" and "Historie"
@@ -304,6 +304,18 @@ void abt_jobInfo::createJobInfoStringList_Append_From(QStringList *strList) cons
 	strList->append(info);
 }
 
+/** \brief Fügt den Absender der Stringliste \a strList hinzu (mit IBAN und BIC) */
+void abt_jobInfo::createJobInfoStringList_Append_From_Sepa(QStringList *strList) const
+{
+	if (!this->m_trans) return; //only if transaction available
+	QString info;
+
+	info = QObject::tr("Von: %1 (%2 - %3)").arg(this->m_trans->getLocalName(),
+						    this->m_trans->getLocalIban(),
+						    this->m_trans->getLocalBic());
+	strList->append(info);
+}
+
 /** \brief Fügt den Empfänger der Stringliste \a strList hinzu */
 void abt_jobInfo::createJobInfoStringList_Append_To(QStringList *strList) const
 {
@@ -316,6 +328,18 @@ void abt_jobInfo::createJobInfoStringList_Append_To(QStringList *strList) const
 	strList->append(info);
 }
 
+/** \brief Fügt den Empfänger der Stringliste \a strList hinzu */
+void abt_jobInfo::createJobInfoStringList_Append_To_Sepa(QStringList *strList) const
+{
+	if (!this->m_trans) return; //only if transaction available
+	QString info;
+
+	info = QObject::tr("Zu:  %1 (%2 - %3)").arg(this->m_trans->getRemoteName().at(0),
+						    this->m_trans->getRemoteIban(),
+						    this->m_trans->getRemoteBic());
+	strList->append(info);
+}
+
 /** \brief Fügt den Verwendungszweck der Stringliste \a strList hinzu */
 void abt_jobInfo::createJobInfoStringList_Append_Purpose(QStringList *strList) const
 {
@@ -395,9 +419,11 @@ void abt_jobInfo::createJobInfoStringList_ForStandingOrders(QStringList *strList
 	QString strCycle;
 	if (cycle <= 1) {
 		if (period == AB_Transaction_PeriodMonthly) {
+			//: prepended for monthly (jeden Monat)
 			strCycle = QObject::tr("jeden");
 		} else {
-			strCycle = QObject::tr("jeden");
+			//: prepended for weekly (jede Woche)
+			strCycle = QObject::tr("jede");
 		}
 	} else {
 		strCycle = QObject::tr("alle %1").arg(cycle);
@@ -527,7 +553,10 @@ void abt_jobInfo::createJobInfoStringList_SepaDebitNote(QStringList *strList) co
 
 void abt_jobInfo::createJobInfoStringList_SepaTransfer(QStringList *strList) const
 {
-	this->createJobInfoStringList_Standard_Text(strList);
+	this->createJobInfoStringList_Append_From_Sepa(strList);
+	this->createJobInfoStringList_Append_To_Sepa(strList);
+	this->createJobInfoStringList_Append_Purpose(strList);
+	this->createJobInfoStringList_Append_Value(strList);
 }
 
 void abt_jobInfo::createJobInfoStringList_Transfer(QStringList *strList) const
