@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.3.0/src/abt_parser.cpp $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/abt_parser.cpp $
  * $Author: Patrick Wacker $
- * $Date: 2012-04-30 22:52:00 +0200 (Mon, 30 Apr 2012) $
- * $Rev: 274 $
+ * $Date: 2013-05-12 21:03:55 +0200 (Sun, 12 May 2013) $
+ * $Rev: 391 $
  *
  * description:
  *	Funktionen die zum parsen des Contextes sowie zum Import und Export
@@ -46,6 +46,44 @@
 #include <aqbanking/accstatus.h>
 
 
+/**
+ * When a AB_TRANSACTION is exported from the history by the AB_IMEXPORTER_CONTEXT,
+ * that is created at abt_history::getContext(), the AB_JOB_TYPE and AB_JOB_STATUS
+ * are stored in the category field of the AB_TRANSACTION (since svn rev310).
+ *
+ * This function searches the category fields for this values and sets the
+ * @a jobType and @a jobStatus to the found values.
+ *
+ * If nothing is found, the @a jobType and @a jobStatus are not changed!
+ *
+ * The values will also be removed from the category field of the AB_TRANSACTION!
+ *
+ */
+//private static
+void abt_parser::getJobStatesFromTransaction(AB_TRANSACTION *t, AB_JOB_TYPE &jobType, AB_JOB_STATUS &jobStatus)
+{
+	const GWEN_STRINGLIST *gsl = AB_Transaction_GetCategory(t);
+	if (!gsl) return; //abort, no category exist
+
+	//we need a copy, so that we don not modify our stringlist while we
+	//iterating over it.
+	GWEN_STRINGLIST *sl = GWEN_StringList_dup(gsl);
+	if (!sl) return; //abort
+
+	for(unsigned int i=0; i<GWEN_StringList_Count(sl); i++) {
+		QString s = QString::fromUtf8(GWEN_StringList_StringAt(sl, i));
+		if (s.startsWith("JobType: ")) {
+			jobType = AB_JOB_TYPE(s.right(s.length() - QString("JobType: ").length()).toInt());
+			AB_Transaction_RemoveCategory(t, s.toUtf8());
+		}
+		if (s.startsWith("JobStatus: ")) {
+			jobStatus = AB_JOB_STATUS(s.right(s.length() - QString("JobStatus: ").length()).toInt());
+			AB_Transaction_RemoveCategory(t, s.toUtf8());
+		}
+	}
+
+	GWEN_StringList_free(sl);
+}
 
 abt_parser::abt_parser()
 {
@@ -143,6 +181,17 @@ AB_IMEXPORTER_CONTEXT *abt_parser::create_ctx_from(const aqb_Accounts *allAccoun
 	return ctx;
 }
 
+/**
+ * parses the supplied AB_IMEXPORTER_CONTEXT \a iec and adds the found
+ * transactions to the corresponding aqb_Accounts \a allAccounts.
+ *
+ * This function should be used to parse the account data and the context which
+ * is returned from the bank.
+ *
+ * (the parse_ctx() function wich also has an abt_history parameter should be
+ *  used so load the saved history transactions).
+ *
+ */
 //static
 void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts)
 {
@@ -186,22 +235,22 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 		logmsg2 = QString("Empfangsdatum:\t%1").arg(
 				abt_conv::GwenTimeToQDate(AB_Message_GetDateReceived(msg))
 				.toString(Qt::DefaultLocaleLongDate));
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 		logmsg2 = QString("Betreff:\t%1").arg(AB_Message_GetSubject(msg));
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 		logmsg2 = QString("Text:\t%1").arg(AB_Message_GetText(msg));
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 		logmsg2 = QString("AccountID: %1  -  UserID: %2").arg(
 				  AB_Message_GetAccountId(msg),
 				  AB_Message_GetUserId(msg));
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		msg = AB_ImExporterContext_GetNextMessage(iec);
 		cnt++;
 	}
 
 	logmsg2 = QString("Count: %1").arg(cnt);
-	qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+	qDebug() << logmsg << logmsg2;
 
 
 	/**********************************************************************/
@@ -219,18 +268,18 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 		*/
 
 		logmsg2 = QString("Name:\t%1").arg(AB_Security_GetName(security));
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		v = AB_Security_GetUnitPriceValue(security);
 		logmsg2 = QString("UnitPriceValue:\t%1").arg(AB_Value_GetValueAsDouble(v));
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		security = AB_ImExporterContext_GetNextSecurity(iec);
 		cnt++;
 	}
 
 	logmsg2 = QString("Count: %1").arg(cnt);
-	qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+	qDebug() << logmsg << logmsg2;
 
 
 	ai=AB_ImExporterContext_GetFirstAccountInfo(iec);
@@ -263,7 +312,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 
 		logmsg2 = QString("%1 (%3) [%2] Owner: %4 ID: %5").arg(
 				   KtoNr, BLZ, Name, Owner, ID);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 
 		/**********************************************************************/
@@ -281,13 +330,13 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 			//Den neuen Account_Status im entsprechenden Object setzen
 			acc->setAccountStatus(as);
 
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			v = AB_AccountStatus_GetBankLine(as);
 			if (v) {
 				logmsg2 = QString("BankLine:\t%1").arg(
 						AB_Value_GetValueAsDouble(v), 0, 'f', 2);
-				qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+				qDebug() << logmsg << logmsg2;
 			}
 
 			b = AB_AccountStatus_GetNotedBalance(as);
@@ -296,7 +345,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 				if (v) {
 					logmsg2 = QString("NotedBalance:\t%1").arg(
 							AB_Value_GetValueAsDouble(v), 0, 'f', 2);
-					qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+					qDebug() << logmsg << logmsg2;
 				}
 			}
 
@@ -306,7 +355,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 				if (v) {
 					logmsg2 = QString("BookedBalance:\t%1").arg(
 							AB_Value_GetValueAsDouble(v), 0, 'f', 2);
-					qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+					qDebug() << logmsg << logmsg2;
 				}
 			}
 
@@ -314,14 +363,14 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 			if (v) {
 				logmsg2 = QString("Disposable:\t%1").arg(
 						AB_Value_GetValueAsDouble(v), 0, 'f', 2);
-				qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+				qDebug() << logmsg << logmsg2;
 			}
 
 			v = AB_AccountStatus_GetDisposed(as);
 			if (v) {
 				logmsg2 = QString("Disposed:\t%1").arg(
 						AB_Value_GetValueAsDouble(v), 0, 'f', 2);
-				qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+				qDebug() << logmsg << logmsg2;
 			}
 
 			as = AB_ImExporterAccountInfo_GetNextAccountStatus(ai);
@@ -329,7 +378,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 		}
 
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 
 
@@ -343,7 +392,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 
 		cnt = AB_ImExporterAccountInfo_GetDatedTransferCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstDatedTransfer(ai);
 		while (t) {
@@ -363,7 +412,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 			l = AB_Transaction_GetPurpose(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("Purpose:\t\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			v = AB_Transaction_GetValue(t);
 			if (v) {
@@ -372,17 +421,17 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 			} else {
 				logmsg2 = QString("Value:\t\tNOT SET!");
 			}
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			l = AB_Transaction_GetRemoteName(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("RemoteName:\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			AB_TRANSACTION_STATUS state = AB_Transaction_GetStatus(t);
 			logmsg2 = QString("Status:\t\t%1 (%2)").arg(state).arg(
 					AB_Transaction_Status_toString(state));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			t = AB_ImExporterAccountInfo_GetNextDatedTransfer(ai);
 		}
@@ -398,7 +447,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 
 		cnt = AB_ImExporterAccountInfo_GetNotedTransactionCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstNotedTransaction(ai);
 		while (t) {
@@ -410,21 +459,21 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 			l = AB_Transaction_GetPurpose(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("Purpose:\t\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			v = AB_Transaction_GetValue(t);
 			logmsg2 = QString("Value:\t\t%1").arg(AB_Value_GetValueAsDouble(v));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			l = AB_Transaction_GetRemoteName(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("RemoteName:\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			AB_TRANSACTION_STATUS state = AB_Transaction_GetStatus(t);
 			logmsg2 = QString("Status:\t\t%1 (%2)").arg(state).arg(
 					AB_Transaction_Status_toString(state));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			t = AB_ImExporterAccountInfo_GetNextNotedTransaction(ai);
 		}
@@ -438,7 +487,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 
 		cnt = AB_ImExporterAccountInfo_GetStandingOrderCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstStandingOrder(ai);
 		while (t) {
@@ -458,21 +507,21 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 			l = AB_Transaction_GetPurpose(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("Purpose:\t\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			v = AB_Transaction_GetValue(t);
 			logmsg2 = QString("Value:\t\t%1").arg(AB_Value_GetValueAsDouble(v));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			l = AB_Transaction_GetRemoteName(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("RemoteName:\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			AB_TRANSACTION_STATUS state = AB_Transaction_GetStatus(t);
 			logmsg2 = QString("Status:\t\t%1 (%2)").arg(state).arg(
 					AB_Transaction_Status_toString(state));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			t = AB_ImExporterAccountInfo_GetNextStandingOrder(ai);
 		}
@@ -486,7 +535,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 
 		cnt = AB_ImExporterAccountInfo_GetTransactionCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstTransaction(ai);
 		while (t) {
@@ -498,21 +547,21 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 			l = AB_Transaction_GetPurpose(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("Purpose:\t\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			v = AB_Transaction_GetValue(t);
 			logmsg2 = QString("Value:\t\t%1").arg(AB_Value_GetValueAsDouble(v));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			l = AB_Transaction_GetRemoteName(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("RemoteName:\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			AB_TRANSACTION_STATUS state = AB_Transaction_GetStatus(t);
 			logmsg2 = QString("Status:\t\t%1 (%2)").arg(state).arg(
 					AB_Transaction_Status_toString(state));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			t = AB_ImExporterAccountInfo_GetNextTransaction(ai);
 		}
@@ -526,7 +575,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 
 		cnt = AB_ImExporterAccountInfo_GetTransferCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstTransfer(ai);
 		while (t) {
@@ -538,21 +587,21 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 			l = AB_Transaction_GetPurpose(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("Purpose:\t\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			v = AB_Transaction_GetValue(t);
 			logmsg2 = QString("Value:\t\t%1").arg(AB_Value_GetValueAsDouble(v));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			l = AB_Transaction_GetRemoteName(t);
 			strList = abt_conv::GwenStringListToQStringList(l);
 			logmsg2 = QString("RemoteName:\t%1").arg(strList.join(" - "));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 			AB_TRANSACTION_STATUS state = AB_Transaction_GetStatus(t);
 			logmsg2 = QString("Status:\t\t%1 (%2)").arg(state).arg(
 					AB_Transaction_Status_toString(state));
-			qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+			qDebug() << logmsg << logmsg2;
 
 
 			t = AB_ImExporterAccountInfo_GetNextTransfer(ai);
@@ -565,7 +614,11 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec, aqb_Accounts *allAccounts
 }
 
 
-// Zum import der History
+/**
+ * parses the supplied AB_IMEXPORTER_CONTEXT \a iec and adds the found
+ * transactions as abt_jobinfo types in the supplied abt_history \a history.
+ *
+ */
 //static
 void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 			   const aqb_Accounts *allAccounts,
@@ -601,7 +654,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 	}
 
 	logmsg2 = QString("Count: %1").arg(cnt);
-	qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+	qDebug() << logmsg << logmsg2;
 
 
 	/**********************************************************************/
@@ -621,7 +674,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 	}
 
 	logmsg2 = QString("Count: %1").arg(cnt);
-	qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+	qDebug() << logmsg << logmsg2;
 
 
 	ai=AB_ImExporterContext_GetFirstAccountInfo(iec);
@@ -651,8 +704,8 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 			continue;
 		}
 
-		logmsg2 = QString("%1 [%2] Owner: %4").arg(KtoNr, BLZ, Owner);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		logmsg2 = QString("%1 [%2] Owner: %3").arg(KtoNr, BLZ, Owner);
+		qDebug() << logmsg << logmsg2;
 
 
 		/**********************************************************************/
@@ -670,7 +723,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 		}
 
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 
 		/**********************************************************************/
@@ -682,7 +735,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 
 		cnt = AB_ImExporterAccountInfo_GetDatedTransferCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstDatedTransfer(ai);
 		while (t) {
@@ -699,9 +752,15 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 			}
 			AB_ACCOUNT *a = acc->get_AB_ACCOUNT();
 
-			abt_jobInfo *ji = new abt_jobInfo(
-					AB_Job_TypeCreateDatedTransfer,
-					AB_Job_StatusFinished, t, a);
+			//default values for a dated transfer
+			AB_JOB_TYPE jtype = AB_Job_TypeCreateDatedTransfer;
+			AB_JOB_STATUS jstatus = AB_Job_StatusFinished;
+
+			//get the jobType and jobStatus from the category field
+			//of the saved transaction.
+			getJobStatesFromTransaction(t, jtype, jstatus);
+
+			abt_jobInfo *ji = new abt_jobInfo(jtype, jstatus, t, a);
 
 			history->add(ji);
 
@@ -717,7 +776,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 
 		cnt = AB_ImExporterAccountInfo_GetNotedTransactionCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstNotedTransaction(ai);
 		while (t) {
@@ -736,7 +795,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 
 		cnt = AB_ImExporterAccountInfo_GetStandingOrderCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstStandingOrder(ai);
 		while (t) {
@@ -753,9 +812,15 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 			}
 			AB_ACCOUNT *a = acc->get_AB_ACCOUNT();
 
-			abt_jobInfo *ji = new abt_jobInfo(
-					AB_Job_TypeCreateStandingOrder,
-					AB_Job_StatusFinished, t, a);
+			//default values for a standing order
+			AB_JOB_TYPE jtype = AB_Job_TypeCreateStandingOrder;
+			AB_JOB_STATUS jstatus = AB_Job_StatusFinished;
+
+			//get the jobType and jobStatus from the category field
+			//of the saved transaction.
+			getJobStatesFromTransaction(t, jtype, jstatus);
+
+			abt_jobInfo *ji = new abt_jobInfo(jtype, jstatus, t, a);
 
 			history->add(ji);
 
@@ -771,7 +836,7 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 
 		cnt = AB_ImExporterAccountInfo_GetTransactionCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstTransaction(ai);
 		while (t) {
@@ -790,26 +855,33 @@ void abt_parser::parse_ctx(AB_IMEXPORTER_CONTEXT *iec,
 
 		cnt = AB_ImExporterAccountInfo_GetTransferCount(ai);
 		logmsg2 = QString("Count: %1").arg(cnt);
-		qDebug(QString(logmsg + logmsg2).toLocal8Bit());
+		qDebug() << logmsg << logmsg2;
 
 		t = AB_ImExporterAccountInfo_GetFirstTransfer(ai);
 		while (t) {
-			QString t_kto = AB_Transaction_GetLocalAccountNumber(t);
-			QString t_blz = AB_Transaction_GetLocalBankCode(t);
-			aqb_AccountInfo *acc = allAccounts->getAccount(t_kto, t_blz);
-			if (!acc) {
+			QString lclKto = AB_Transaction_GetLocalAccountNumber(t);
+			QString lclBLZ = AB_Transaction_GetLocalBankCode(t);
+
+			aqb_AccountInfo *lclAcc = allAccounts->getAccount(lclKto, lclBLZ);
+			if (!lclAcc) {
 				// keinen passenden Account gefunden, Nächste
 				qWarning() << logmsg << "No matching account found!"
-						     << "( KTO:" << t_kto
-						     << " - BLZ:" << t_blz << ")";
+						     << "( KTO:" << lclKto
+						     << " - BLZ:" << lclBLZ << ")";
 				t = AB_ImExporterAccountInfo_GetNextTransfer(ai);
 				continue;
 			}
-			AB_ACCOUNT *a = acc->get_AB_ACCOUNT();
 
-			abt_jobInfo *ji = new abt_jobInfo(
-					AB_Job_TypeTransfer,
-					AB_Job_StatusFinished, t, a);
+			//default values for a transfer
+			AB_JOB_TYPE jtype = AB_Job_TypeTransfer;
+			AB_JOB_STATUS jstatus = AB_Job_StatusFinished;
+
+			//get the jobType and jobStatus from the category field
+			//of the saved transaction.
+			getJobStatesFromTransaction(t, jtype, jstatus);
+
+			abt_jobInfo *ji = new abt_jobInfo(jtype, jstatus, t,
+							  lclAcc->get_AB_ACCOUNT());
 
 			history->add(ji);
 
