@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 2011 Patrick Wacker
+ * Copyright (C) 2011-2013 Patrick Wacker
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
  * Software Foundation; either version 2 of the License, or (at your option)
@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.3.0/src/widgets/widgetrecurrence.cpp $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/widgets/widgetrecurrence.cpp $
  * $Author: Patrick Wacker $
- * $Date: 2012-03-24 12:48:42 +0100 (Sat, 24 Mar 2012) $
- * $Rev: 178 $
+ * $Date: 2013-06-16 10:51:35 +0200 (Sun, 16 Jun 2013) $
+ * $Rev: 480 $
  *
  * description:
  *
@@ -92,7 +92,7 @@ widgetRecurrence::widgetRecurrence(QWidget *parent) :
 	this->dateLast = new widgetDate(tr("Letztmalig"), Qt::AlignTop, this);
 	this->checkBoxNoEnd = new QCheckBox(tr("bis auf weiteres"), this);
 	this->dateNext = new widgetDate(tr("nächste Ausf."), Qt::AlignTop, this);
-	this->dateNext->setReadOnly(true);
+	this->dateNext->setDisabled(true);
 
 	connect(this->dateFirst, SIGNAL(dateChanged(QDate)),
 		this, SLOT(setNextExecutionDay(QDate)));
@@ -455,16 +455,21 @@ const QDate widgetRecurrence::getNextExecutionDate() const
 
 
 //public slot
+/** \brief set the period (monthly or weekly)
+ *
+ * This sets the period only if allowed and not already set.
+ */
 void widgetRecurrence::setPeriod(AB_TRANSACTION_PERIOD period)
 {
 	QRadioButton *btn = (QRadioButton*)this->radio_group->button(period);
 
-	if (!btn) return;
+	if (!btn)
+		return; //no button for period available, abort
 
-	if (btn->isEnabled()) {
+	if (btn->isEnabled() && !btn->isChecked()) {
+		//button not checked, set checked and update widget
 		btn->setChecked(true);
-	} else {
-		btn->setChecked(false);
+		this->selectedPeriodChanged(period); //updates the whole widget
 	}
 }
 
@@ -540,6 +545,7 @@ void widgetRecurrence::setLimitAllowChangeLastExecutionDate(int b)
 {
 	// -1 == nicht erlaubt (form disabled), sonst unbekannt o. erlaubt
 	this->dateLast->setDisabled(b == -1);
+	this->checkBoxNoEnd->setDisabled(b == -1);
 }
 
 //public Slot
