@@ -16,10 +16,10 @@
  ******************************************************************************
  * Dont forget: svn propset svn:keywords "Date Author Rev HeadURL" filename
  ******************************************************************************
- * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.3.0/src/widgets/widgettransfer.cpp $
+ * $HeadURL: http://schmufu.dyndns.org/svn/ab_transfers/tags/0.0.4.1/src/widgets/widgettransfer.cpp $
  * $Author: Patrick Wacker $
- * $Date: 2012-05-04 18:52:50 +0200 (Fri, 04 May 2012) $
- * $Rev: 277 $
+ * $Date: 2013-05-20 16:30:59 +0200 (Mon, 20 May 2013) $
+ * $Rev: 415 $
  *
  * description:
  *
@@ -38,6 +38,7 @@
 #include <QtCore/QDebug>
 
 #include "../aqb_accountinfo.h"
+#include "../globalvars.h"	//for the global "banking" object
 
 widgetTransfer::widgetTransfer(AB_JOB_TYPE type,
 			       const aqb_AccountInfo *lclAccount,
@@ -70,7 +71,6 @@ widgetTransfer::widgetTransfer(AB_JOB_TYPE type,
 
 	//Die noch nicht implementierten Aufträge gesondert behandeln
 	switch(this->m_type) {
-	case AB_Job_TypeSepaTransfer :
 	case AB_Job_TypeEuTransfer :
 	case AB_Job_TypeDebitNote :
 	case AB_Job_TypeSepaDebitNote : {
@@ -112,6 +112,9 @@ widgetTransfer::widgetTransfer(AB_JOB_TYPE type,
 	case AB_Job_TypeTransfer : // Normal Transfer
 		this->my_create_transfer_form(true);
 		break;
+	case AB_Job_TypeSepaTransfer : // SEPA Transfer
+		this->my_create_sepatransfer_form(true);
+		break;
 	case AB_Job_TypeCreateStandingOrder :
 		this->my_create_standing_order_form(true);
 		break;
@@ -154,12 +157,13 @@ widgetTransfer::widgetTransfer(AB_JOB_TYPE type,
 
 	this->setAllLimits(this->m_limits);
 
-	this->pushButtonRevert = new QPushButton(QIcon::fromTheme("edit-undo"),
-						 tr("Rückgängig"), this);
-	this->pushButtonCancel = new QPushButton(QIcon::fromTheme("dialog-close"),
-						 tr("Abbrechen"), this);
-	this->pushButtonOK = new QPushButton(QIcon::fromTheme("dialog-ok-apply"),
-					     tr("Senden"), this);
+	QIcon ico;
+	ico = QIcon::fromTheme("edit-undo", QIcon(":/icons/edit-undo"));
+	this->pushButtonRevert = new QPushButton(ico, tr("Rückgängig"), this);
+	ico = QIcon::fromTheme("dialog-close", QIcon(":/icons/dialog-close"));
+	this->pushButtonCancel = new QPushButton(ico, tr("Abbrechen"), this);
+	ico = QIcon::fromTheme("dialog-ok-apply", QIcon(":/icons/ok"));
+	this->pushButtonOK = new QPushButton(ico, tr("Senden"), this);
 	connect(this->pushButtonOK, SIGNAL(clicked()),
 		this, SLOT(onOkButtonPressed()));
 	connect(this->pushButtonCancel, SIGNAL(clicked()),
@@ -230,6 +234,16 @@ void widgetTransfer::my_createNotAvailableJobText()
 			"beeinflusst werden.").arg(
 					abt_conv::JobTypeToQString(this->m_type),
 					BankName, KontoName));
+	if (this->m_type == AB_Job_TypeSepaTransfer) {
+		description->setText(description->text().append(
+			tr("<br /><br />"
+			   "Hinweis für SEPA Überweisungen:<br />"
+			   "SEPA Überweisungen werden durch AqBanking erst ab "
+			   "Version 5.0.27 unterstützt (aktuell verwendet wird "
+			   "Version %1)<br />"
+			   "Eventuell ist ein Update von AqBanking erforderlich!"
+			   ).arg(banking->getAqBankingVersion())));
+	}
 	description->setWordWrap(true);
 	description->setAlignment(Qt::AlignTop | Qt::AlignLeft);
 	description->setMinimumWidth(350);
@@ -298,6 +312,22 @@ void widgetTransfer::my_create_transfer_form(bool newTransfer)
 	this->layoutMain->addWidget(this->textKey, 0, Qt::AlignRight);
 }
 
+//private
+void widgetTransfer::my_create_sepatransfer_form(bool newTransfer)
+{
+	this->setWindowTitle(tr("SEPA Überweisung"));
+	this->my_create_local_remote_horizontal(newTransfer, true);
+	this->my_create_value_with_label_left();
+	this->my_create_purpose();
+//	this->my_create_textKey();
+
+	this->layoutMain->addLayout(this->layoutAccount);
+	this->layoutMain->addLayout(this->layoutValue);
+	this->layoutMain->addLayout(this->layoutPurpose);
+//	this->layoutMain->addWidget(this->textKey, 0, Qt::AlignRight);
+}
+
+
 //pricate
 void widgetTransfer::my_create_dated_transfer_form(bool newTransfer)
 {
@@ -320,10 +350,10 @@ void widgetTransfer::my_create_dated_transfer_form(bool newTransfer)
 }
 
 //private
-void widgetTransfer::my_create_local_remote_horizontal(bool newTransfer)
+void widgetTransfer::my_create_local_remote_horizontal(bool newTransfer, bool sepaFields)
 {
 	this->my_create_localAccount_groupbox(newTransfer);
-	this->my_create_remoteAccount_groupbox(newTransfer);
+	this->my_create_remoteAccount_groupbox(newTransfer, false, true, sepaFields);
 
 	this->layoutAccount = new QHBoxLayout();
 	this->layoutAccount->addWidget(this->groupBoxLocal);
@@ -360,13 +390,14 @@ void widgetTransfer::my_create_localAccount_groupbox(bool /* newTransfer */,
 
 //private
 void widgetTransfer::my_create_remoteAccount_groupbox(bool /* newTransfer */,
-						      bool allowLocal,
-						      bool allowKnownRecipent)
+						      bool allowLocal /* = false */,
+						      bool allowKnownRecipient /* = true */,
+						      bool sepaFields /* = false */)
 {
 	if (allowLocal) {
-		//Wenn der RemoteAccount local drops akzeptiert ist die
-		//erstellung für ein UmbuchungsWidget und wir Zeigen die
-		//als remoteAccount auch eine LocalAccountAuswahl an
+		//if allowLocal is true, the "remote" account should be a
+		//local account and we use the same widget for the "remote"
+		//account input as for the local-account input.
 		this->groupBoxRemote = new QGroupBox(tr("Empfänger"));
 		QVBoxLayout *gbrl = new QVBoxLayout();
 		this->remoteAccount = new widgetAccountData(this,
@@ -378,9 +409,9 @@ void widgetTransfer::my_create_remoteAccount_groupbox(bool /* newTransfer */,
 		//Die RemoteKontoEingabe ermöglichen
 		this->groupBoxRemote = new QGroupBox(tr("Empfänger"));
 		QVBoxLayout *gbrl = new QVBoxLayout();
-		this->remoteAccount = new widgetAccountData(this, NULL, NULL);
+		this->remoteAccount = new widgetAccountData(this, NULL, NULL, sepaFields);
 		this->remoteAccount->setAllowDropAccount(allowLocal);
-		this->remoteAccount->setAllowDropKnownRecipient(allowKnownRecipent);
+		this->remoteAccount->setAllowDropKnownRecipient(allowKnownRecipient);
 		gbrl->addWidget(this->remoteAccount);
 		this->groupBoxRemote->setLayout(gbrl);
 	}
@@ -455,23 +486,6 @@ void widgetTransfer::my_create_recurrence()
 
 
 
-//private
-void widgetTransfer::setLocalFromAccount(const aqb_AccountInfo *acc)
-{
-	qWarning() << "OBSOLET function called  -  widgetTransfer::setLocalFromAccount()";
-	if (this->localAccount != NULL) {
-		this->localAccount->setName(acc->OwnerName());
-		this->localAccount->setAccountNumber(acc->Number());
-		this->localAccount->setBankCode(acc->BankCode());
-		this->localAccount->setBankName(acc->BankName());
-	} else {
-		qWarning() << this << "setLocalFromAccount() called without"
-				<< "having a localAccountWidget!";
-	}
-
-}
-
-
 //private
 void widgetTransfer::setAllLimits(const abt_transactionLimits *limits)
 {
@@ -488,8 +502,12 @@ void widgetTransfer::setAllLimits(const abt_transactionLimits *limits)
 	if (this->recurrence) this->recurrence->setDisabled(dis);
 	if (this->datedDate) this->datedDate->setDisabled(dis);
 
-	if (dis) return; //Abbruch wenn keine Limits vorhanden sind
+	if (dis) {
+		qDebug() << Q_FUNC_INFO << "No Limits exists. Transaction not supported!";
+		return; //Abbruch wenn keine Limits vorhanden sind
+	}
 
+	limits->printAllAsDebug();
 
 	if (this->localAccount != NULL) {
 		this->localAccount->setLimitMaxLenAccountNumber(limits->MaxLenLocalAccountNumber);
@@ -505,6 +523,7 @@ void widgetTransfer::setAllLimits(const abt_transactionLimits *limits)
 		this->remoteAccount->setLimitMaxLenAccountNumber(limits->MaxLenRemoteAccountNumber);
 		this->remoteAccount->setLimitMaxLenBankCode(limits->MaxLenRemoteBankCode);
 		this->remoteAccount->setLimitMaxLenName(limits->MaxLenRemoteName);
+		this->remoteAccount->setLimitMaxLenIban(limits->MaxLenRemoteIban);
 	}
 
 	if (this->value != NULL) {
@@ -637,7 +656,7 @@ bool widgetTransfer::isGeneralInputOk(QString &errorMsg) const
 		errorMsg.append(tr("<b><br />"
 				   "Der Auftrag '%1'' ist bei dem in Absender "
 				   "gewählten Konto nicht verfügbar.<br />"
-				   "Bitte wählen Sie einen Absender bei dem der "
+				   "Bitte wählen Sie ein Konto bei dem der "
 				   "Auftrag auch ausgeführt werden kann.</b>"
 				   "<br />").arg(abt_conv::JobTypeToQString(this->m_type)));
 		//wir dürfen nicht weiter testen, da die weiteren Überprüfungen
@@ -654,26 +673,33 @@ bool widgetTransfer::isGeneralInputOk(QString &errorMsg) const
 	}
 
 	if (this->remoteAccount != NULL) {
+		//check between internal- and other transfers differ
 		if (this->m_type == AB_Job_TypeInternalTransfer) {
+			//the remoteAccount widget must have a known account!
 			if (this->remoteAccount->getAccount() == NULL) {
 				errorMsg.append(tr(" - <b>Programmierfehler:</b> remoteAccount->getAccount == NULL<br />"));
-			} else { //Bei Umbuchung muss Absender und Empfänger unterschiedlich sein
-				if (this->localAccount != NULL) {
-					if (this->localAccount->getAccount() ==
-					    this->remoteAccount->getAccount()) {
-						errorMsg.append(tr(" - Absender und Empfänger müssen unterschiedlich sein<br />"));
-					}
-				}
 			}
+			//the values of the selected local and remote account
+			//are checked further down.
+
 		} else {
 			if (this->remoteAccount->getName().isEmpty()) {
 				errorMsg.append(tr(" - Empfängername nicht eingegeben<br />"));
 			}
-			if (this->remoteAccount->getAccountNumber().isEmpty()) {
-				errorMsg.append(tr(" - Empfänger Kontonummer nicht eingegeben<br />"));
-			}
-			if (this->remoteAccount->getBankCode().isEmpty()) {
-				errorMsg.append(tr(" - Empfänger Bankleitzahl nicht eingegeben<br />"));
+			if (this->m_type == AB_Job_TypeSepaTransfer) {
+				if (this->remoteAccount->getIBAN().isEmpty()) {
+					errorMsg.append(tr(" - Empfänger IBAN nicht eingegeben<br />"));
+				}
+				if (this->remoteAccount->getBIC().isEmpty()) {
+					errorMsg.append(tr(" - Empfänger BIC nicht eingegeben<br />"));
+				}
+			} else {
+				if (this->remoteAccount->getAccountNumber().isEmpty()) {
+					errorMsg.append(tr(" - Empfänger Kontonummer nicht eingegeben<br />"));
+				}
+				if (this->remoteAccount->getBankCode().isEmpty()) {
+					errorMsg.append(tr(" - Empfänger Bankleitzahl nicht eingegeben<br />"));
+				}
 			}
 			if (this->remoteAccount->getBankName().isEmpty()) {
 				errorMsg.append(tr(" - Empfänger Institut nicht eingegeben<br />"));
@@ -763,21 +789,44 @@ bool widgetTransfer::isGeneralInputOk(QString &errorMsg) const
 	//Prüfung der Daten von recurrence
 	this->isRecurrenceInputOk(errorMsg);
 
+
+	//Check the values for an internal transfer
 	if (this->m_type == AB_Job_TypeInternalTransfer) {
-		if (this->remoteAccount->getAccount() != NULL) {
-			if (this->localAccount->getAccount() ==
-			    this->remoteAccount->getAccount()) {
-				errorMsg.append(tr(" - Umbuchung von ein auf dasselbe Konto nicht möglich<br />"));
+		//local- and remoteAccountWidget must exist (NULL Pointer dereference)
+		if (this->localAccount && this->remoteAccount) {
+			if (this->remoteAccount->getAccount() == NULL) {
+				errorMsg.append(tr(" - <b>Programmierfehler:</b> remoteAccount muss bei Umbuchung einen Account besitzen!<br />"));
+			} else {
+				const aqb_AccountInfo* la = this->localAccount->getAccount(); //local Account
+				const aqb_AccountInfo* ra = this->remoteAccount->getAccount(); //remote Account
+				if (la == ra) {
+					errorMsg.append(tr(" - Absender und Empfänger müssen unterschiedlich sein<br />"
+							   "&nbsp;&nbsp;<i>(Umbuchung von ein auf dasselbe Konto nicht möglich)</i><br />"));
+				} else if (la->BankCode() != ra->BankCode()) {
+					//local and remote account must be at the same bank
+					errorMsg.append(tr(" - Umbuchungungen sind nur zwischen Konten des selben<br />"
+							   "&nbsp;&nbsp;Instituts möglich<br />"));
+				} // else if (la->OwnerName() != ra->OwnerName()) {
+					//local and remote account must have the same owner/user
+					/** \todo Wie wird richtig zwischen 2 konten mit
+					 *	  unterschiedlichen Besitzern unterschieden?
+					 *	  Über den "Owner" oder über den in aqBanking
+					 *	  vorhandenen "User"?
+					 *
+					 *	  Jedes Konto hat einen Owner und ist einem
+					 *	  User zugewiesen. Die User-Verknüpfung
+					 *	  bestimmt z.B. welches Sicherheitsverfahren
+					 *	  verwendet wird.
+					 */
+//					errorMsg.append(tr(" - Absender- und Empfängerkonto müssen derselben Person<br />"
+//							   "&nbsp;&nbsp;zugeordnet sein<br />"));
+//				}
 			}
-			if (this->localAccount->getAccount()->BankCode() !=
-			    this->remoteAccount->getAccount()->BankCode()) {
-				errorMsg.append(tr(" - Umbuchungungen sind nur zwischen Konten desselben Instituts möglich<br />"));
-			}
-		} else {
-			errorMsg.append(tr(" - <b>Programmierfehler:</b> remoteAccount muss bei Umbuchung einen Account besitzen!<br />"));
 		}
 	}
 
+
+	//safety check for modifying transfers
 	if ((this->m_type == AB_Job_TypeModifyDatedTransfer) ||
 	    (this->m_type == AB_Job_TypeModifyStandingOrder)) {
 		if (this->m_origTransaction == NULL) {
@@ -790,8 +839,9 @@ bool widgetTransfer::isGeneralInputOk(QString &errorMsg) const
 		return true;
 	}
 
-	//: the same string as used for displaying programmer failures
-	if (errorMsg.contains(tr("Programmierfehler"))) {
+	//append msg that the author make a mistake and that the user can not
+	//correct this if the errorMsg contains "Programmierfehler"
+	if (errorMsg.contains(tr("Programmierfehler", "must be the same string as used in \"Programming Error\" strings"))) {
 		errorMsg.append(tr("<br />"
 				   "<hr>"
 				   "Es sind Fehler aufgetreten an denen Sie nichts ändern "
@@ -1050,6 +1100,10 @@ void widgetTransfer::setValuesFromTransaction(const abt_transaction *t)
 			this->remoteAccount->setAccountNumber(t->getRemoteAccountNumber());
 			this->remoteAccount->setBankCode(t->getRemoteBankCode());
 			this->remoteAccount->setBankName(t->getRemoteBankName());
+			//we can simple set the iban and bic values, because
+			//the widget only sets values that are possible
+			this->remoteAccount->setIBAN(t->getRemoteIban());
+			this->remoteAccount->setBIC(t->getRemoteBic());
 		}
 	}
 
